workwithservers

package
v0.0.0-...-2a31ee1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SendCommandToServer

func SendCommandToServer(ip, userRole, password, command, portSSH string) (string, error)

SendCommandToServer ip-ip of server, pasw - pasw of server, command - command to request portSSH - if empty like("") will be by default 22 if not empty will be custom port return a output of your command, time to establish 3 sec can custom.

Types

This section is empty.

Jump to