Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SendCommandToServer ¶
SendCommandToServer ip-ip of server, pasw - pasw of server, command - command to request portSSH - if empty like("") will be by default 22 if not empty will be custom port return a output of your command, time to establish 3 sec can custom.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.